@@ -7,9 +7,7 @@ sub prepare {
     my $info    = shift;
 
     my $address = $info->{'address'};
-    return unless($address);
-    return if($address =~ /^$RE{'URI'}/);
-    return unless($address =~ /\w+@\w+/);
+    return unless(isEmail($address));
     return(1);
 }
 
@@ -19,12 +17,20 @@ sub convert {
     my $iodef = shift;
 
     my $address = $info->{'address'};
-    return($iodef) unless($address);
-    return($iodef) unless($address =~ /\w+@\w+/);
+    return unless(isEmail($address));
 
     $iodef->add('IncidentEventDataFlowSystemNodeAddresscategory','e-mail');
     $iodef->add('IncidentEventDataFlowSystemNodeAddress',$address);
     return $iodef;
 }
 
+sub isEmail {
+    my $e = shift;
+    return unless($e);
+    return if($e =~ /^$RE{'URI'}/);
+    return if($e =~ /^$RE{'URI'}{'HTTP'}{-scheme => 'https'}$/);
+    return unless(lc($e) =~ /[a-z0-9_.-]+\@[a-z0-9.-]+\.[a-z0-9.-]{2,5}/);
+    return(1);
+}
+
 1;
